/*==========================================================================*\
|                                                                            |
| LowLevelFunc.h                                                             |
|                                                                            |
| Low Level function prototypes, macros, and pin-to-signal assignments       |
| regarding to user's hardware                                               |
|----------------------------------------------------------------------------|
| Project:              MSP430 Replicator                                    |
| Developed using:      IAR Embedded Workbench 3.40B [Kickstart]             |
|----------------------------------------------------------------------------|
| Author:               FRGR                                                 |
| Version:              1.5                                                  |
| Initial Version:      04-17-02                                             |
| Last Change:          20-12-05                                             |
|----------------------------------------------------------------------------|
| Version history:                                                           |
| 1.0 04/02 FRGR        Initial version.                                     |
| 1.1 04/02 FRGR        Included SPI mode to speed up shifting function by 2.|
|                       (JTAG control now on Port5)                          |
| 1.2 06/02 ALB2        Formatting changes, added comments. Removed code used|
|                       for debug purposes during development.               |
| 1.3 08/02 ALB2        Initial code release with Lit# SLAA149.              |
| 1.4 09/05 SUN1        Software delays redesigned to use TimerA harware;    |
|                       see MsDelay() routine. Added TA constant.            |
| 1.5 12/05 STO         Added RESET pin definition                           |
|----------------------------------------------------------------------------|
| Designed 2002 by Texas Instruments Germany                                 |
\*==========================================================================*/

/****************************************************************************/
/* Macros and Pin-to-Signal assignments which have to be programmed         */
/* by the user. This implementation assumes use of an MSP430F149 as the host*/
/* controller and the corresponding hardware given in the application       */
/* report TBD Appendix A.                                                   */
/*                                                                          */
/* The following MSP430 example acts as a hint of how to generally          */
/* implement a micro-controller programmer solution for the MSP430 flash-   */
/* based devices.                                                           */
/****************************************************************************/

#include "JTAGfunc.h"

#ifndef __BYTEWORD__
#define __BYTEWORD__
typedef unsigned short  word;
typedef unsigned char   byte;
#endif

// Constants for runoff status
#define STATUS_ERROR     0      // false
#define STATUS_OK        1      // true
#define STATUS_ACTIVE    2
#define STATUS_IDLE      3

/****************************************************************************/
/* Define section for user, related to the controller used (here MSP430F149)*/
/****************************************************************************/

#define FREQUENCY   8000   // CPU frequency in kHz

// Comment the following two definitons to disable SPI communication mode and
// enable the bit-bang implementation.

/*----------------------------------------------------------------------------
   Macros for processing the JTAG port and Vpp pins
*/

typedef union outPortUnion {
    unsigned char value;
    struct opBitsStr {
        unsigned char tck:1;
        unsigned char tdi:1;
        unsigned char zero:1;           // tdo
        unsigned char tms:1;
        unsigned char rst:1;
        unsigned char bit5:1;
        unsigned char bit6:1;
        unsigned char bit7:1;
    } bits;
} outPortType;

extern outPortType out_word;

VOID WINAPI UpdateTxBuf(BYTE txd);
unsigned char WINAPI readTDOBit(void);
__inline void ClrTMS(void)        {out_word.bits.tms = 0;UpdateTxBuf(out_word.value);}
__inline void SetTMS(void)        {out_word.bits.tms = 1;UpdateTxBuf(out_word.value);}
__inline void ClrTDI(void)        {out_word.bits.tdi = 0;UpdateTxBuf(out_word.value);}
__inline void SetTDI(void)        {out_word.bits.tdi = 1;UpdateTxBuf(out_word.value);}
__inline void ClrTCK(void)        {out_word.bits.tck = 0;UpdateTxBuf(out_word.value);}
__inline void SetTCK(void)        {out_word.bits.tck = 1;UpdateTxBuf(out_word.value);}
__inline void ClrTCLK(void)       {out_word.bits.tdi = 0;UpdateTxBuf(out_word.value);}
__inline void SetTCLK(void)       {out_word.bits.tdi = 1;UpdateTxBuf(out_word.value);}
__inline int  StoreTCLK(void)     {return(out_word.bits.tdi);}
__inline void RestoreTCLK(int x)  {out_word.bits.tdi = x;UpdateTxBuf(out_word.value);}
__inline int  ScanTDO(void)       {return(readTDOBit());}
#if 0
__inline void SetRST(void)        {out_word.bits.rst = 1;UpdateTxBuf(out_word.value);}
__inline void ClrRST(void)        {out_word.bits.rst = 0;UpdateTxBuf(out_word.value);}
#else
__inline void SetRST(void)        {}
__inline void ClrRST(void)        {}
#endif

/*----------------------------------------------------------------------------
   Low Level function prototypes
*/

void MsDelay(word milliseconds);      // millisecond delay loop, uses Timer_A
void usDelay(word microeconds);       // microsecond delay loop, uses nops
void InitController(void);
int  InitTarget(void);
void ReleaseTarget(void);
void Shift(word Format, word Data);   // used for IR- as well as DR-shift
word ShiftX(word Format, word Data);  // used for IR- as well as DR-shift
void TDOisInput(void);
void TCLKstrobes(word Amount);
void ShowStatus(word Status, word Index);
