		.LIST	OFF
;/*==========================================================================*\
;|                                                                            |
;| LowLevelFunc.h                                                             |
;|                                                                            |
;| Low Level function prototypes, macros, and pin-to-signal assignments       |
;| regarding to user's hardware                                               |
;|----------------------------------------------------------------------------|
;| Project:              MSP430 Replicator                                    |
;| Developed using:      IAR Embedded Workbench 2.31C                         |
;|----------------------------------------------------------------------------|
;| Author:               FRGR                                                 |
;| Version:              1.3                                                  |
;| Initial Version:      04-17-02                                             |
;| Last Change:          08-29-02                                             |
;|----------------------------------------------------------------------------|
;| Version history:                                                           |
;| 1.0 04/02 FRGR        Initial version.                                     |
;| 1.1 04/02 FRGR        Included SPI mode to speed up shifting function by 2.|
;|                       (JTAG control now on Port5)                          |
;| 1.2 06/02 ALB2        Formatting changes, added comments. Removed code used|
;|                       for debug purposes during development.               |
;| 1.3 08/02 ALB2        Initial code release with Lit# SLAA149.              |
;|----------------------------------------------------------------------------|
;| Designed 2002 by Texas Instruments Germany                                 |
;\*==========================================================================*/

;/****************************************************************************/
;/* Macros and Pin-to-Signal assignments which have to be programmed         */
;/* by the user. This implementation assumes use of an MSP430F149 as the host*/
;/* controller and the corresponding hardware given in the application       */
;/* report TBD Appendix A.                                                   */
;/*                                                                          */
;/* The following MSP430 example acts as a hint of how to generally          */
;/* implement a micro-controller programmer solution for the MSP430 flash-   */
;/* based devices.                                                           */
;/****************************************************************************/

STATUS_ERROR	.equ	0			; // false
STATUS_OK	.equ	1			; // true
STATUS_ACTIVE	.equ	2
STATUS_IDLE	.equ	3

;// Instructions for the JTAG control signal register
IR_CNTRL_SIG_16BIT	.equ	0C8h	;// 0x13 original values
IR_CNTRL_SIG_CAPTURE	.equ	028h	;// 0x14
IR_CNTRL_SIG_RELEASE	.equ	0A8h	;// 0x15
;// Instructions for the JTAG Fuse
IR_PREPARE_BLOW		.equ	044h	;// 0x22
IR_EX_BLOW		.equ	024h	;// 0x24 
;// Instructions for the JTAG data register
IR_DATA_16BIT		.equ	082h	;// 0x41
IR_DATA_QUICK		.equ	0C2h	;// 0x43
;// Instructions for the JTAG PSA mode
IR_DATA_PSA		.equ	022h	;// 0x44
IR_SHIFT_OUT_PSA	.equ	062h	;// 0x46
;// Instructions for the JTAG address register
IR_ADDR_16BIT		.equ	0C1h	;// 0x83
IR_ADDR_CAPTURE		.equ	021h	;// 0x84
IR_DATA_TO_ADDR		.equ	0A1h	;// 0x85
;// Bypass instruction
IR_BYPASS		.equ	0FFh	;// 0xFF

;// JTAG identification value for all existing Flash-based MSP430 devices
JTAG_ID			.equ	089h

;// Constants for data formats, dedicated addresses
F_BYTE			.equ	8
F_WORD			.equ	16
V_RESET			.equ	0FFFEh

;// Constants for flash erasing modes
ERASE_MASS		.equ	0A506h
ERASE_MAIN		.equ	0A504h
ERASE_SGMT		.equ	0A502h

;/********************************************************************/
;/* t@C        : config.inc                                   */
;/* e              : R8C/15                                       */
;/* 쐬t          : 2005.04.14                                   */
;/********************************************************************/
;============== ߰Ē` =============================================
LEDPWR		.btequ	6,p1			; |[gP16
LEDRED		.btequ	7,p1			; |[gP17
LEDDNL		.btequ	7,p1			; |[gP16
LEDGREEN	.btequ	6,p1			; |[gP16
LEDRD		.btequ	6,p1			; |[gP16
LEDWR		.btequ	6,p1			; |[gP16
TDI		.btequ	1,p1			; |[gP11
TMS		.btequ	3,p1			; |[gP13
TCK		.btequ	0,p1			; |[gP10
TDO		.btequ	2,p1			; |[gP12
TCLK		.btequ	TDI			; TDI
TEST		.btequ	3,p3			; |[gP33
RST		.btequ	4,p3			; |[gP34
nCONFIG		.btequ	TMS
DCLK		.btequ	TCK
CONF_DONE	.btequ	TDO
DATA		.btequ	TDI

STS_OK		.equ	0			; 
STS_PTYER	.equ	1			; 
STS_UNDEF	.equ	2			; 
STS_CDONE	.equ	3			; CONF_DONE ُ
STS_FAILED	.equ	4			; ގs
VER		.equ	1			; 
REV		.equ	0			; 
VERREV		.equ	(VER+(REV*256))		; 

;============== ϸے` ==============================================
;--- TMS = 0 ɂ ---
ClrTMS		.macro
		bclr	TMS			; 
		.endm
;--- TMS = 1 ɂ ---
SetTMS		.macro
		bset	TMS			; 
		.endm
;--- TDI = 0 ɂ ---
ClrTDI		.macro
		bclr	TDI			; 
		.endm
;--- TDI = 1 ɂ ---
SetTDI		.macro
		bset	TDI			; 
		.endm
;--- TCK = 0 ɂ ---
ClrTCK		.macro
		bclr	TCK			; 
		.endm
;--- TCK = 1 ɂ ---
SetTCK		.macro
		bset	TCK			; 
		.endm
;--- TCLK = 0 ɂ ---
ClrTCLK		.macro
		bclr	TCLK			; 
		.endm
;--- TCLK = 1 ɂ ---
SetTCLK		.macro
		bset	TCLK			; 
		.endm
;--- TCLK 擾 ---
StoreTCLK	.macro	reg
		mov.b	p1,reg			; 
		.endm
;--- TCLK  ---
RestoreTCLK	.macro	reg
		btst	1,reg			; c = TDI
		bmc	TCLK			; 
		.endm
;--- BUSY-LED \ ---
led_busy	.macro	reg
		cmp.b	#0Dh,reg		; t[I?
		bmnz	c			; c = (r0l != 0x0D)?  1 : 0
		bnand	LEDPWR			; c &= ~p1.0
		bmc	LEDPWR			; 
		.endm

;============== RAM̈ ==============================================
SFRTOP		.equ	0000h
SFREND		.equ	02FFh
RAMTOP		.equ	0400h			; RAM擪
RAMEND		.equ	07FFh			; RAMI[
STACK		.equ	0800h			; 
DROMTOP		.equ	2400h			; data ROM
DROMEND		.equ	2BFFh
PROMTOP		.equ	0C000h			; program ROM
PROMEND		.equ	0FFFFh
VERVECT		.EQU	0FE00h			; Declares start address of variable vector table
FIXVECT		.EQU	0FFDCh			; Declares fixed interrupt vector address

wkbuf		.equ	00400h			; Mޯ̧
BUFSIZE		.equ	256			; :256޲
DEVICE		.equ	wkbuf+BUFSIZE		; ޲:2޲
;// Global target device ID (e.g. 0xF149); is set 
;// during GetDevice() function execution.

;ُ
JTYP		.equ	1			; 0:ؼ٤1:

		.LIST	ON
